Method: Eve::API::Services::Character#kill_log

Defined in:
lib/eve/api/services/character.rb

#kill_log(options = {}) ⇒ Object

This API call only returns 1000 entries. Often, you will need to gather all entries, and not just the most recent 1000. If this is true for your application, simply pass the :walk option and this EVE library will automatically “walk” backward in time until the server reports that there are no more entries available.

Walking is disabled by default, so you need to pass the :walk => true option if you wish to enable this.

full API key



34
35
36
37
38
# File 'lib/eve/api/services/character.rb', line 34

def kill_log(options = {})
  options.reverse_merge!({:walk => false, :walk_id => 'before_kill_id', :walk_association => 'kills' })
  validate_options(options, :walk, :walk_id, :walk_association)
  request(:char, :kill_log, options)
end